@@ -95,24 +95,35 @@ class MikrotikApiClient:
             nt = namedtuple('Row', fields)
         return [nt(*[x.get(k) for k in keys]) for x in results]
 
-    async def _get_results(self, cmd, include_disabled=False, props=None, query=None):
-        try:
-            return await asyncio.wait_for(self._get_results_data(
-                cmd, include_disabled, props, query),
-                                          timeout=self._timeout)
-        except asyncio.CancelledError:
-            logging.info('Cancelled "%s" operation for %s', cmd, self.host)
-            await self.close()
-            raise
-        except asyncio.TimeoutError:
-            logging.info('Operation "%s" to host %s timed out', cmd, self.host)
-            await self.close()
-            raise
-        except Exception as err:
-            logging.info('Error calling "%s" on host %s: %s (%s)', cmd, self.host,
-                         type(err).__name__, err)
-            await self.close()
-            raise
+    async def _get_results(self,
+                           cmd,
+                           include_disabled=False,
+                           props=None,
+                           query=None,
+                           num_retries=1):
+        err = None
+        for retry_num in range(num_retries + 1):
+            if retry_num > 0:
+                await asyncio.sleep(2**retry_num)
+            try:
+                return await asyncio.wait_for(self._get_results_data(
+                    cmd, include_disabled, props, query),
+                                              timeout=self._timeout)
+            except asyncio.CancelledError:
+                logging.info('Cancelled "%s" operation for %s', cmd, self.host)
+                await self.close()
+                raise
+            except asyncio.TimeoutError:
+                logging.info('Operation "%s" to host %s timed out', cmd, self.host)
+                await self.close()
+                raise
+            except Exception as e:
+                logging.info('Error calling "%s" on host %s: %s (%s)', cmd, self.host,
+                             type(e).__name__, e)
+                err = e
+                await self.close()
+        logging.info('Mikrotik get "%s" to %s retried out', cmd, self.host)
+        raise err
 
     async def connect(self):
         self._reader, self._writer = await asyncio.open_connection(self.host,
